@@ -1,7 +1,8 @@
 import asyncio
+import pickle
 from inspect import getsource
 from os import PathLike
-from typing import Callable, List, Tuple, Union, Optional
+from typing import Callable, List, Tuple, Union, Optional, Any
 
 import nbformat
 from nbclient import NotebookClient
@@ -148,6 +149,15 @@ class Notebook:
 
         return result
 
+    async def store(self, name: str, value: Any) -> NotebookReference:
+        encoded_value = pickle.dumps(value)
+        await self.execute_code(f'''
+            import pickle
+            {name} = pickle.loads({encoded_value})
+        ''')
+
+        return self.ref(name)
+
     async def execute_fun(self, fun: Callable) -> NotebookCell:
         """
         strip header from function and execute in notebook context
@@ -175,6 +185,11 @@ class Notebook:
             line = loc[i].lstrip()
             indent = len(loc[i]) - len(line)
 
+            # remove empty lines
+            if line == '':
+                del loc[i]
+                continue
+
             # compare indent
             if inner_fun is not None and indent <= inner_fun:
                 inner_fun = None
@@ -182,13 +197,8 @@ class Notebook:
             if return_found is not None and indent < return_found:
                 return_found = None
 
-            # remove empty lines
-            if line == '':
-                del loc[i]
-                continue
-
             # skip inner functions
-            if line.startswith('def '):
+            if line.startswith('def ') or line.startswith('async def '):
                 inner_fun = indent
 
             if inner_fun:
